=====
NLPIA
=====


The code and data for [Natural Language Processing in Action](https://www.manning.com/books/natural-language-processing-in-action)


Description
===========

A community-developed book about building Natural Language Processing pipelines for prosocial chatbots that contribute to communities.

